@@ -98,7 +98,7 @@ class Object(object):
             if k in self:
                 name = resolution.get(k, None)
                 if not name:
-                    raise TypeError("Method {0:s} of 1:s} conflicts with {2:s}".format(k, repr(trait), repr(self)))
+                    raise TypeError("Method {0:s} of {1:s} conflicts with {2:s}".format(k, repr(trait), repr(self)))
                 else:
                     self.behaviors[name] = v
             else:
@@ -199,45 +199,6 @@ class Object(object):
         default = default.eval(context) if default else runtime.find("None")
         return receiver.attrs.get(key, default)
 
-    # Traits Operations
-
-    @method()
-    def use(self, receiver, context, m, trait, resolution=None):
-        trait = trait.eval(context)
-
-        if receiver.__hastrait__(trait):
-            raise TypeError("{0:s} already uses 1:s}".format(repr(receiver), repr(trait)))
-
-        resolution = runtime.state.frommio(resolution.eval(context)) if resolution is not None else {}
-
-        receiver.__addtrait__(trait, **resolution)
-
-        return receiver
-
-    @method()
-    def delTrait(self, receiver, context, m, trait):
-        trait = trait.eval(context)
-
-        if not receiver.__hastrait__(trait):
-            raise TypeError("{0:s} does not use {1:s}".format(repr(receiver), repr(trait)))
-
-        receiver.__deltrait__(trait)
-
-        return receiver
-
-    @method()
-    def hasTrait(self, receiver, context, m, trait):
-        trait = trait.eval(context)
-        return runtime.find("True") if receiver.__hastrait__(trait) else runtime.find("False")
-
-    @method("traits", True)
-    def getTraits(self, receiver, context, m):
-        return runtime.find("List").clone(receiver.traits.keys())
-
-    @method("behaviors", True)
-    def getBehaviors(self, receiver, context, m):
-        return runtime.find("List").clone(receiver.behaviors.keys())
-
     # Block Operations
 
     @method()
@@ -325,8 +286,10 @@ class Object(object):
     def evalArg(self, receiver, context, m, *args):
         if len(args) > 1:
             return runtime.find("Tuple").clone(tuple(arg.eval(context) for arg in args))
-        else:
+        elif len(args) == 1:
             return args[0].eval(context)
+        else:
+            return runtime.find("None")
 
     @method()
     def do(self, receiver, context, m, expression):
