@@ -1,24 +1,36 @@
+from pytest import fixture
+
+
+from mio import runtime
+
+
+@fixture(scope="session")
+def mio(request):
+    runtime.init()
+    return runtime.state
+
+
 def test_closure(mio, capfd):
     mio.eval("""
-        foo = method(
-            return method(
+        foo = block(
+            block(
                 print("foo")
             )
         )
     """)
 
     mio.eval("x = foo()")
-    assert mio.eval("x()").value is None
+    assert mio.frommio(mio.eval("x()")) is None
     out, err = capfd.readouterr()
     assert out == "foo\n"
 
 
 def test_closure_locals(mio):
     mio.eval("""
-        counter = method(n,
-            return block(
-                self n = n + 1
-                return n
+        counter = block(n,
+            block(
+                this n = n + 1
+                n
             )
         )
     """)
@@ -28,14 +40,16 @@ def test_closure_locals(mio):
 
     assert mio.eval("x()") == 2
     assert mio.eval("y()") == 3
+    assert mio.eval("x()") == 3
+    assert mio.eval("y()") == 4
 
 
 def test_closure_locals2(mio):
     mio.eval("""
-        counter = method(n,
-            return block(
+        counter = block(n,
+            block(
                 n = n + 1
-                return n
+                n
             )
         )
     """)
