@@ -78,6 +78,10 @@ def test_hash(mio):
     assert mio.eval("Object __hash__()") == hash(runtime.find("Object"))
 
 
+def test_hash_invalid(mio):
+    assert mio.frommio(mio.eval("Dict __hash__()")) is None
+
+
 def test_id(mio):
     assert mio.eval("(Object id) == (Object id)")
 
@@ -191,3 +195,24 @@ def test_primitive2(mio):
 
 def test_state(mio):
     assert repr(mio.eval("state")) == "NormalState()"
+
+
+def test_callable(mio):
+    mio.eval("""
+        Foo = Object clone() do (
+            __call__ = method("foo")
+        )
+    """)
+
+    assert mio.eval("Foo()") == "foo"
+
+
+def test_callable2(mio):
+    mio.eval("""
+        Foo = Object clone() do (
+            foo = method("foo")
+        )
+    """)
+
+    with raises(TypeError):
+        assert mio.eval("Foo()", reraise=True)
